export interface StakeKeys {
  stakeKey?: string;
  stakeKeyBech32?: string;
}

export type JSONValue =
  | string
  | number
  | boolean
  | null
  | { [property: string]: JSONValue }
  | JSONValue[];
export enum MetadataStandard {
  CIP100 = 'CIP100',
  CIP119 = 'CIP119',
}

export type DRepMetadata = {
  givenName: {} | string;
  email?: {} | string;
  bio?: {} | string;
  objectives?: {} | string;
  motivations?: {} | string;
  qualifications?: {} | string;
  references: any[];
  image?: {
    contentUrl: string;
    sha256: string;
  };
  paymentAddress?: string;
};
export type MetadataSaveResponse = {
  deletedAt: string;
  id: number;
  createdAt: string;
  updatedAt: string;
  name: string;
  hash: string;
  content: string;
};
export type IPFSResponse = {
  name: string;
  ipfs_hash: string;
  size: number;
};
export type NotificationType = 'info' | 'warning' | 'error';
export type Notification = {
  id: number;
  title: string;
  message: string;
  type: NotificationType;
  createdAt: Date;
  isRead: boolean;
  isArchived: boolean;
  deletedAt: Date;
  isPersistent: boolean;
  recipient: string;
};
export type Metrics = {
  totalRegisteredDReps: number;
  totalLiveStake: number;
  totalActiveDReps: number;
  totalGovernanceActions: number;
  totalVotingPower: number;
  totalRegisteredStakeAddresses: number;
};

export interface ProposalMetrics {
  totalProposals: number;
  totalAda: number;
  meanUsdToAdaConversionRate: number;
  medianUsdToAdaConversionRate: number;
  modeUsdToAdaConversionRate: number;
  intersectNamedAdministrator: number;
}
export interface ProposalAnimatedMetricProps {
  value: number;
  isAda?: boolean;
  isPercentage?: boolean;
  isBillion?: boolean;
  isMillion?: boolean;
  isThousand?: boolean;
  duration?: number;
  isLoading?: boolean;
  search?: string;
}

export interface ProposalMetricsCardProps {
  value: number;
  label: string;
  isAda?: boolean;
  isPercentage?: boolean;
  isBillion?: boolean;
  isMillion?: boolean;
  isThousand?: boolean;
  tooltip?: string;
  isLoading?: boolean;
  search?: string;
}

export type VoteMetadata = {
  vote: string;
  voterId: string;
  voteTxHash: string;
  voteTxIndex: number;
};

export type MappedOutSubmitMetadataExtra = {
  drepUpdate: DRepMetadata;
  voteUpdate: VoteMetadata;
};
export type SubmitMetadataType = 'drepUpdate' | 'voteUpdate';
export type SubmitMetadataExtra = {
  [K in SubmitMetadataType]?: MappedOutSubmitMetadataExtra[K];
};
